//==============================================================================
// PROJECT      = Bootloader
// MODULE       = bl78k0_kx2_const.h
// SHORT DESC.  = Bootloader constants
// DEVICE       = 78K0/Kx2
// VERSION      = 1.0
// DATE         = 05.12.2006
// LAST CHANGE  =
// =============================================================================
// By:          NEC Electronics (Europe) GmbH
//              Arcadiastrasse 10
//              D-40472 Duesseldorf
// =============================================================================



#ifndef __BL78K0_KX2_CONST_H
#define __BL78K0_KX2_CONST_H


#ifndef __SPL78K0_TYPES_H_INCLUDED
#define __SPL78K0_TYPES_H_INCLUDED

//*****************************************************************************
// type definitions
//*****************************************************************************
typedef unsigned char       u08;
typedef unsigned int        u16;
typedef unsigned long int   u32;

#endif



#define CODEBANK_START_USER     0x8000    // code bank start addr.
#define CODEBANK_END_USER       0xBFFF    // code bank end addr.


//*****************************************************************************
// define location addresses for CRC, update byte etc. for bootloader update
//*****************************************************************************
#define CRC_BL_HEADER           0x0FFC      // address for flash word with crc,
                                            // will be written at bootcluster copy
                                            // 0x0FFC is 0, 0x0FFD is 0
                                            // 0x0FFE is CRC
#define BL_CRC_ADDRESS          0x0FFE      // bootloader crc address

#define FIRST_APP_BLOCK         0x04        // first app. block
#define LAST_BOOTL_CODE_ADDR    0x0FFB      // must be mod 4 = 3
#define FIRST_ADDR_BCLUSTER1    0x1000      // first addr. of bootcluster 1

//*****************************************************************************
// define location addresses for CRC, clear pattern byte etc. for app. update
//*****************************************************************************
#define CRC_APP_LOCATION        0x1004      // application crc addr.
#define APP_START_ADR           0x1008      // start addr. of app. for crc calc
#define APP_END_ADR             0x100C      // end addr of app. for CRC calc.
#define APP_VALID_PATTERN       0x00        // valid app. pattern

//*****************************************************************************
// bootloader dumps
//*****************************************************************************

#define VERSION_TEXT            "\n\n\rBV: "

#ifndef BOOTL_UPDATE_ALLOWED
  #define UPDATE_TEXT           "\n\rUpdate?y or n"
#else
  #define UPDATE_TEXT           "\n\rUpdate?a or b"
#endif


#define START_SOFT_TEXT         "\n\rStart app."
#define HEX_FILE_RECEIVED       "\n\rFile OK!"
#define ILLEGAL_CHARACTERS      "\n\rStop send"
#define SEND_FILE_TEXT          "\n\rSend file"
#define HEX_FILE_TIMEOUT        " X"
#define BAD_APP_CRC             "\n\n\r!APP"
#define UPDATE_READY            "\n\rREADY"



#endif


