//==============================================================================
// PROJECT      = Bootloader
// MODULE       = bl78k0_kx2_user.h
// SHORT DESC.  = User defines
// DEVICE       = 78K0/Kx2
// VERSION      = 1.0
// DATE         = 05.12.2006
// LAST CHANGE  =
// =============================================================================
// By:          NEC Electronics (Europe) GmbH
//              Arcadiastrasse 10
//              D-40472 Duesseldorf
// =============================================================================



#ifndef __BL78K0_KX2_USER_H
#define __BL78K0_KX2_USER_H


#define BOOTLOADER_VERSION      "0.1"     // bootloader version

#define BOOTL_UPDATE_ALLOWED              // switch between bootloader update allowed
                                          // or not allowed. If these const. is commented
                                          // out, the user can't update the bootloader


//#define STOP_RX_WITH_TIMEOUT            // read app. note, before activate this const.

#define CLOCK_FREQUENCY         20        // clock frequency in MHz


#define IMS_REGISTER_VALUE      0xCC  // set IMS the internal memory size switching register
#define IXS_REGISTER_VALUE      0x00  // set IXS internal expansion RAM size switching register

// Definition of banks count. Comment it out, if non banked model is used.
//#define CODEBANK_BANKS_USER     0x06      // bank count(include bank 0)

// Define this constant only if you don't uses banking!
#define FLASH_END_ADDR          0xEFFF      // Flash end address

//*****************************************************************************
// fill byte
//*****************************************************************************

#define FILL_BYTE               0xFF      // fill byte pattern

#define LAST_APP_BLOCK          0x7F      // last app. block


//*****************************************************************************
// buffer definitions
//*****************************************************************************

#define BYTES_AFTER_RX_STOP     8 // if bootloader send XOFF then the transmitter
                                  // can send this count of bytes after XOFF

#define RX_BUFFER_SIZE          200       // receive buffer size


//*****************************************************************************
// timeout factor's for 50ms intervall
//*****************************************************************************

#define ILLEGAL_BYTE_TIMEOUT      2       // 100ms -> first illegal byte
#define ILLEGAL_SEND_TIMEOUT      14      // 700ms -> wait on illegal rx timeout
#define MESSAGE_TIMEOUT_K_50MS    40      // 2s -> timeout at message send
#define RECEIVE_TIMEOUT_K_50MS    60      // 3s -> wait on rx 'y' or 'n'
#define FIRST_BYTE_HEX_TIMEOUT    200     // 10s -> wat on hex file


//*****************************************************************************
// timeout factor's for 2ms intervall
//*****************************************************************************
#define RX_BYTE_TIMEOUT_HEX_2MS  70 // 140ms -> file transfer byte timeout
#define READY_TO_RX_TIMEOUT      2  // 4ms -> set interface ready to rx timeout
#define STOP_RX_TIMEOUT          2  // 4ms -> set stopr send timeout




//*****************************************************************************
// type definitions
//*****************************************************************************
#ifndef __SPL78K0_TYPES_H_INCLUDED
#define __SPL78K0_TYPES_H_INCLUDED

typedef unsigned char       u08;
typedef unsigned int        u16;
typedef unsigned long int   u32;


#endif


struct u08_struct{
  u08 U08_1;
  u08 U08_2;
  u08 U08_3;
  u08 U08_4;
};

struct u16_struct{
  u16 U16_1;
  u16 U16_2;
};


union union_addr{
  struct u08_struct u08_access;
  struct u16_struct u16_access;
  u32 u32_access;
};

#define STOP_WATCHDOG   RCM_bit.no1 = 1;  // Internal low-speed oscillator stopped
#define START_WATCHDOG  RCM_bit.no1 = 0;  // Internal low-speed oscillator stopped


#endif

