//==============================================================================
// PROJECT      = K_Line - Taste it!-2
// MODULE       = reactime.c
// SHORT DESC.  = -
// DEVICE       = 78K0/KF2 (uPD78F0547D)
// VERSION      = 1.0
// DATE         = 19.10.2005
// LAST CHANGE  = -
// =============================================================================
// Description: This sample program demonstrates a reaction time measurement.
//              After the button SW3 is pressed the application waits for a random
//              time duration between 0.50 and 3.45 seconds. Then the measurement
//              starts by incrementing a reaction counter every 50ms. The actual
//              counter value is shown by a bar graph using the character LC display
//              until the next keystroke of button SW3. When the button SW3 is pressed
//              again, the measurement stops and the reaction time is shown on the
//              LC display. Pressing button SW2 starts a new measuring cycle.
// =============================================================================
// By:          NEC Electronics (Europe) GmbH
//              Arcadiastrasse 10
//              D-40472 Duesseldorf
// =============================================================================

//-----------------------------------------------------------------------------
// Include files
//-----------------------------------------------------------------------------
#include "defines.h"
#include "lcd.h"

#include <intrinsics.h>

#include "io78f054780.h"

//-----------------------------------------------------------------------------
// Option Byte
//-----------------------------------------------------------------------------
//#pragma location = "OPTBYTE"
//__root const unsigned char opbytes[2]={0x00,0x00};

//---------------------------------------------------------------------------------
// Security ID CODE: for OCD on-chip debugging only / 78K0 CPU module + QB-78K0MINI
//---------------------------------------------------------------------------------
//#pragma location = "SECUID"
//__root const unsigned char secuid[11]={0x02,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff};

//-----------------------------------------------------------------------------
// Function prototyps
//-----------------------------------------------------------------------------
       void          vFlashLED      (unsigned char);  // flash ucLEDs's
       void          vWait25        (unsigned char);  // n *  25ms delay
       unsigned char ucRandom       (void);           // generation of random-number
extern void          vHardwareInit  (void);           // initialization Hardware
extern void          vSoftwareInit  (void);           // initialization bit variables

//-----------------------------------------------------------------------------
// Global variables
//-----------------------------------------------------------------------------
volatile unsigned char        bTimer1Flag;          // status Flag Timer1
volatile unsigned char        bTimer2Flag;          // status Flag Timer2
volatile unsigned char        bTimer50Flag;         // status Flag 8bit Timer 50
volatile unsigned char        bKey3Flag;            // status Key3
volatile unsigned char        bKey2Flag;            // status Key2

unsigned char        count10;

unsigned char        lcd_bar;
unsigned char        lcd_pos;

//-----------------------------------------------------------------------------
// Constants
//-----------------------------------------------------------------------------

const char *text01="NEC  K_Line ";
const char *text02="Taste it!-2 ";
const char *text03="ReactionTime";
const char *text04="measurement!";
const char *text05=" Press SW3  ";
const char *text06=" to start   ";
const char *text07=" msec ";
const char *text08=" Press SW2  ";
const char *text09=" to restart ";
const char *text10=" Try again! ";
const char *text11="            ";
const char *text12=" R E A D Y  ";
const char *text13="    G O     ";

const char bgpat0[8] = {0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10};
const char bgpat1[8] = {0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18};
const char bgpat2[8] = {0x1c,0x1c,0x1c,0x1c,0x1c,0x1c,0x1c,0x1c};
const char bgpat3[8] = {0x1e,0x1e,0x1e,0x1e,0x1e,0x1e,0x1e,0x1e};
const char bgpat4[8] = {0x1f,0x1f,0x1f,0x1f,0x1f,0x1f,0x1f,0x1f};

//-----------------------------------------------------------------------------
// Module name: ucRandom
// Description: This module generates a pseudo-random number.
//-----------------------------------------------------------------------------
unsigned char ucRandom(void)
{
    return ((((TM50)%60)+10)*2);       // pseudo-random number between 20 ... 138
}


//-----------------------------------------------------------------------------
// Module name: vFlashLED
// Description: This module flashes all LEDs n times.
//-----------------------------------------------------------------------------
void vFlashLED(unsigned char Number)
{
    while(Number>0) {
       LED=0x00;                       // all LEDs on
       vWait25(20);                    // delay of 500 ms
       LED=0xFF;                       // all LEDs off
       vWait25(20);                    // delay of 500 ms
       Number--;
    }
    return;
}

//-----------------------------------------------------------------------------
// Module name: vWait25
// Description: This module delays the program for n * 50 ms.
//-----------------------------------------------------------------------------
void vWait25(unsigned char Number)
{
  bTimer2Flag = FALSE;                 // reset flag timer2
  STARTTIMER2;                         // start Timer2
  while(Number > 0) {
         while(bTimer2Flag == FALSE){  // wait for Timer Interrupt
          __no_operation();
          __no_operation();
        }
        bTimer2Flag = FALSE;           // reset status flag Timer2
        Number--;
    }
  STOPTIMER2;                          // stop Timer2
  return;
}

//-----------------------------------------------------------------------------
// Module name: vWait10
// Description: This module delays the program for 10 ms.
//-----------------------------------------------------------------------------
void vWait10()
{
  bTimer1Flag = FALSE;                 // reset flag timer1
  STARTTIMER1;                         // start Timer1
  while(bTimer1Flag == FALSE);         // wait for Timer Interrupt
  STOPTIMER1;                          // stop Timer1
  return;
}

//-----------------------------------------------------------------------------
// Module name: Output_result
// Description: Ouput of measured reaction time.
//-----------------------------------------------------------------------------
void Output_result()
{
      unsigned char bcd01,bcd02;
      bcd01=count10/10;
      bcd02=count10%10;
      if (count10>=60)
      {
          LCD_cursor(0x40);
          LCD_string(&text10[0]);
          return;
      }
      LCD_cursor(0x42);
      if(!bcd01)  LCD_cursor(0x43);
      else LCD_data(bcd01);
      LCD_data(bcd02);
      LCD_data(0x0);
      LCD_string(&text07[0]);
}

//-----------------------------------------------------------------------------
// main function
//-----------------------------------------------------------------------------
void main( void )
{
    __disable_interrupt();             // disable all interrupts
    vHardwareInit();                   // peripheral settings
    vSoftwareInit();                   // variable Initialization
    LCD_init();                        // LCD Initialization
    LCD_inst(0x01);                    // clear display

    LCD_write_CGRAM(0x00,&bgpat0[0]);  // write display character RAM
    LCD_write_CGRAM(0x01,&bgpat1[0]);
    LCD_write_CGRAM(0x02,&bgpat2[0]);
    LCD_write_CGRAM(0x03,&bgpat3[0]);
    LCD_write_CGRAM(0x04,&bgpat4[0]);

    __enable_interrupt();              // enable all interrupts

    LCD_cursor(0x0);
    LCD_string(&text01[0]);
    LCD_cursor(0x40);
    LCD_string(&text02[0]);
    vWait25(80);                      // delay

    while(TRUE)
    {
       LCD_cursor(0x0);
       LCD_string(&text03[0]);
       LCD_cursor(0x40);
       LCD_string(&text04[0]);
       vWait25(80);
       LCD_cursor(0x0);
       LCD_string(&text05[0]);
       LCD_cursor(0x40);
       LCD_string(&text06[0]);

       bKey3Flag=0;                        // Reset Key3 Flag
       while(bKey3Flag==0) vFlashLED(1);   // wait start signal

       LCD_cursor(0x40);
       LCD_string(&text12[0]);

       vWait25(ucRandom());               // wait a random time 0.50 ... 3.45 s

       LCD_cursor(0x00);
       LCD_string(&text11[0]);
       LCD_cursor(0x40);
       LCD_string(&text13[0]);
       LED=0x00;
       count10=0;
       lcd_pos=0;
       lcd_bar=0;
       STARTTIMER1;                        // start Timer1
       bKey3Flag=0;                        // Reset Key3 Flag

       while ((count10<60)&& bKey3Flag==0)
       {
           vWait10();               // wait 10ms
           count10++;
           LCD_cursor(lcd_pos);
           LCD_char(lcd_bar);
           if (lcd_bar<4)
           {
               lcd_bar++;
           }
           else
           {
               lcd_bar=0;
               lcd_pos++;
           }
       }
       STOPTIMER1;                 // stop Timer1
       LED=0xff;
       bKey2Flag=0;                // Reset Key2 Flag
       while(bKey2Flag==0)
       {
            vWait25(20);                    // delay
            Output_result();
            vWait25(20);                    // delay
            LCD_cursor(0x40);
            LCD_string(&text11[0]);
       }
    }
}


